 ; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1
[Command]
name = "AIflag"
command = a,a,a,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag2"
command = a,b,a,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag3"
command = a,a,c,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag4"
command = a,a,z,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag5"
command = a,a,a,x,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag6"
command = a,a,a,y,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag7"
command = a,c,c,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag8"
command = a,b,z,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag9"
command = a,a,c,a,x,a,a,a,a,a,a,a
time =1
[Command]
name = "AIflag10"
command = a,a,z,a,z,a,a,a,x,a,a,a
time = 1
[Command]
name = "AIflag11"
command = a,a,a,x,c,a,a,x,a,a,a,a
time = 1
[Command]
name = "AIflag12"
command = a,a,a,x,c,a,a,a,a,x,a,a
time = 1
[Command]
name = "AIflag13"
command = a,a,a,x,c,a,a,a,a,x,a,a
time = 1
[Command]
name = "AIflag14"
command = a,a,a,x,c,a,a,x,a,a,a,a
time = 1
[Command]
name = "AIflag15"
command = a,a,a,x,c,a,a,x,a,a,a,x
time = 1
[Command]
name = "AIflag16"
command = a,a,a,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag17"
command = a,b,a,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag18"
command = a,a,c,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag19"
command = a,a,z,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag20"
command = a,a,a,x,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag21"
command = a,a,a,y,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag22"
command = a,c,c,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag23"
command = a,b,z,a,a,a,a,a,a,a,a,a
time = 1
[Command]
name = "AIflag24"
command = a,a,c,a,x,a,a,a,a,a,a,a
time =1
[Command]
name = "AIflag25"
command = a,a,z,a,z,a,a,a,x,a,a,a
time = 1
[Command]
name = "AIflag26"
command = a,a,a,x,c,a,a,x,a,a,a,a
time = 1
[Command]
name = "AIflag27"
command = a,a,a,x,c,a,a,a,a,x,a,a
time = 1
[Command]
name = "AIflag28"
command = a,a,a,x,c,a,a,a,a,x,a,a
time = 1
[Command]
name = "AIflag29"
command = a,a,a,x,c,a,a,x,a,a,a,a
time = 1
[Command]
name = "AIflag30"
command = a,a,a,x,c,a,a,x,a,a,a,x
time = 1
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "up" ;Required (do not remove)
command = U
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.

[Statedef -1]

[State 0, Explod]
type = Explod
triggerall=!Numexplod(8101919)
triggerall=!ishelper
trigger1 = command = "AIflag"
trigger2 = command = "AIflag2"
trigger3 = command = "AIflag3"
trigger4 = command = "AIflag4"
trigger5 = command = "AIflag5"
trigger6 = command = "AIflag6"
trigger7 = command = "AIflag7"
trigger8 = command = "AIflag8"
trigger9 = command = "AIflag9"
trigger10 = command = "AIflag10"
trigger11 = command = "AIflag11"
trigger12 = command = "AIflag12"
trigger13 = command = "AIflag13"
trigger14 = command = "AIflag14"
trigger15 = command = "AIflag15"
trigger16 = command = "AIflag16"
trigger17 = command = "AIflag17"
trigger18 = command = "AIflag18"
trigger19 = command = "AIflag19"
trigger20 = command = "AIflag20"
trigger21 = command = "AIflag21"
trigger22 = command = "AIflag22"
trigger23 = command = "AIflag23"
trigger24 = command = "AIflag24"
trigger25 = command = "AIflag25"
trigger26 = command = "AIflag26"
trigger27 = command = "AIflag27"
trigger28 = command = "AIflag28"
trigger29 = command = "AIflag29"
trigger30 = command = "AIflag30"
anim = 9999
ID = 8101919
pos = 0,0
postype = p1  ;p2,front,back,left,right
facing = 1
vfacing = 1
bindtime = -1
removetime=-1
ignorehitpause = 1

[State -1, Run Fwd]
type = ChangeState
value = 240
triggerall=numexplod(8101919)
triggerall=numprojid(8100721)
triggerall=roundstate=2
triggerall=!Ishelper
triggerall =life<=150
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 220
triggerall=roundstate=2
triggerall=numexplod(8101919)
triggerall=!Ishelper
triggerall =numexplod(2221919)>=4
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 230
triggerall=roundstate=2
triggerall=numexplod(8101919)
triggerall=!Ishelper
triggerall =numexplod(8931919)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 200
triggerall=roundstate=2
triggerall=numexplod(8101919)
triggerall=!Ishelper
triggerall =numexplod(9311919)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Run Fwd]
type = ChangeState
value = 210
triggerall=roundstate=2
triggerall=numexplod(8101919)
triggerall=!Ishelper
triggerall =!numexplod(9311919)
triggerall =!numexplod(8931919)
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 240
triggerall=!numexplod(8101919)
triggerall=!Ishelper
trigger1 = command = "y"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 230
triggerall=!Ishelper
trigger1 = command = "x"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 220
triggerall=!Ishelper
trigger1 = command = "c"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 210
triggerall=!Ishelper
trigger1 = command = "b"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 200
triggerall=!Ishelper
trigger1 = command = "a"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall=!Ishelper
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall=!Ishelper
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;󒆃Wv
[State -1, Jump Strong Kick]
type = ChangeState
value = 45
triggerall=!Ishelper
triggerall = command = "up"
triggerall = var(4) = 0
trigger1 = statetype = A
trigger1 = ctrl

;Wv
[State -1, Jump Strong Kick]
type = ChangeState
value = 40
triggerall=!Ishelper
triggerall = command = "holdup"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = anim = 100

;s
[State -1, Jump Strong Kick]
type = ChangeState
value = 20
triggerall=!Ishelper
triggerall = statetype = S
triggerall = anim != 100
triggerall = ctrl
trigger1 = command = "holdfwd"
trigger2 = command = "holdback"

;
[State -1, Jump Strong Kick]
type = ChangeState
value = 180
triggerall=!Ishelper
triggerall = alive
triggerall = stateno != 170
triggerall = stateno != [180,181]
triggerall = roundstate = 4
trigger1 = win

;
[State -1, Jump Strong Kick]
type = ChangeState
value = 170
triggerall=!Ishelper
triggerall = alive
triggerall = stateno != 170
triggerall = stateno != [180,181]
triggerall = roundstate = 4
trigger1 = !win


